#include <cpu.h>
#include <instructions/instructions.h>
#pragma once

int syscall_handle(cpu_status_t* status, uint32_t origin);

void syscall_bdisp_allclr_ddvram(cpu_status_t* status);
void syscall_bdisp_putdisp_dd(cpu_status_t* status);
void syscall_get_vram_address(cpu_status_t* status);
void syscall_save_disp(cpu_status_t* status);
void syscall_restore_disp(cpu_status_t* status);
void syscall_bdisp_allclr_vram(cpu_status_t* status);

void syscall_locate(cpu_status_t* status);
void syscall_print(cpu_status_t* status);

void syscall_malloc(cpu_status_t* status);

void syscall_getkey(cpu_status_t* status);